@@ -19,6 +19,19 @@ class ParametrizedModelState:
     ]
     param_aux: _steppers.NoStepValue
 
+    def __repr__(self):
+        model_state_summary = _utils.indent_repr(
+            _utils.summarize_object(self.model_state), 2
+        )
+        param_aux_summary = _utils.indent_repr(
+            _utils.summarize_object(self.param_aux), 2
+        )
+        return f"""\
+ParametrizedModelState(
+  model_state={model_state_summary},
+  param_aux={param_aux_summary},
+)"""
+
 
 def _init_none(init_state, model):
     return None
@@ -83,3 +96,18 @@ class ParametrizedModel:
         ):
             setattr(obj, name, val)
         return obj
+
+    def __repr__(self):
+        model_summary = _utils.indent_repr(_utils.summarize_object(self.model), 2)
+        param_func_summary = _utils.indent_repr(
+            _utils.summarize_object(self.param_func), 2
+        )
+        init_param_aux_func_summary = _utils.indent_repr(
+            _utils.summarize_object(self.init_param_aux_func), 2
+        )
+        return f"""\
+ParametrizedModel(
+  model={model_summary},
+  param_func={param_func_summary},
+  init_param_aux_func={init_param_aux_func_summary},
+)"""
